overlay_plotly: Plot overlaying eQTL and GWAS data using plotly

View source: R/overlay_plotly.R

overlay_plotlyR Documentation

Plot overlaying eQTL and GWAS data using plotly

Description

Produces a scatter plot using plotly of embedded eQTL data acquired through the LDlink API via link_eqtl() overlaid on GWAS data. As each SNP may have eQTLs with multiple genes in multiple tissues, the method used is to select the gene/tissue eQTL with the lowest p-value. SNPs are matched by rsID.

Usage

overlay_plotly(
  loc,
  gene_filter = NULL,
  tissue_filter = NULL,
  pcutoff = 5e-08,
  eqtl_scheme = NULL,
  xlab = NULL,
  ylab = NULL,
  marker_outline = "grey",
  marker_size = 7,
  recomb_col = "blue",
  showlegend = TRUE,
  show_annot = TRUE,
  height = NULL,
  webGL = TRUE
)

Arguments

loc

Object of class 'locus' to use for plot. See locus.

gene_filter

Character vector of genes to filter eQTL results.

tissue_filter

Character vector of tissues to filter eQTL results.

pcutoff

Cut-off for p value significance. Defaults to p = 5e-08. Set to NULL to disable.

eqtl_scheme

Vector of colours for eQTL genes, which can be named.

xlab

x axis title.

ylab

y axis title.

marker_outline

Specifies colour for outlining points.

marker_size

Value for size of markers in plotly units.

recomb_col

Colour for recombination rate line if recombination rate data is present. Set to NA to hide the line. See link_recomb() to add recombination rate data.

showlegend

Logical whether to show a legend for the scatter points.

show_annot

Logical whether to show an annotation of how many eQTL SNPs were retrieved from LDlink and how many are shown.

height

Height in pixels (optional, defaults to automatic sizing).

webGL

Logical whether to use webGL or SVG for scatter plot.

Value

A plotly scatter plot.

See Also

link_eqtl() locus_plotly()


locuszoomr documentation built on Oct. 9, 2026, 5:06 p.m.