sanity_check: Sanity checks on GWAS dataframes

View source: R/sanity_check.R

sanity_checkR Documentation

Sanity checks on GWAS dataframes

Description

Performs sanity checks on GWAS dataframes to check similar chromosome content, overlap in SNP ids and alignment of SNPs by chromosome/position.

Usage

sanity_check(data, data2, chrom = NULL, pos = NULL, p = NULL, labs = NULL)

Arguments

data

Dataframe of GWAS results with columns for chromosome, position, p value and SNP rs IDs. Data.tables are coerced to dataframe.

data2

Dataframe of 2nd GWAS results for comparison.

chrom

Vector determines which column in data and data2 contains chromosome information. If NULL or NA tries to autodetect the columns. The 1st element refers to data and 2nd element refers to data2.

pos

Determines which column in data and data2 contains position information. See chrom.

p

Determines which column in data and data2 contains SNP p-values. See chrom.

labs

Determines which column in data and data2 contains SNP rs IDs. See chrom.

Value

No return value. Prints diagnostic messages.


locuszoomr documentation built on Oct. 9, 2026, 5:06 p.m.