| set_layers | R Documentation |
Uses graphics::layout() to set up multiple locus plots aligned in a column.
set_layers(n = 1, heights = c(rep(3, n), 2), rev = FALSE)
n |
Number of plots (not including gene tracks on bottom) |
heights |
Vector of length |
rev |
Logical whether to reverse plotting order and plot from bottom to top |
Sets graphics::layout() to enable multiple plots aligned in a column. The
gene track is assumed to be positioned on the bottom. Returns par()
invisibly so that layout can be reset to default at the end of plotting.
graphics::layout()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.