| sanity_check | R Documentation |
Performs sanity checks on GWAS dataframes to check similar chromosome content, overlap in SNP ids and alignment of SNPs by chromosome/position.
sanity_check(data, data2, chrom = NULL, pos = NULL, p = NULL, labs = NULL)
data |
Dataframe of GWAS results with columns for chromosome, position, p value and SNP rs IDs. Data.tables are coerced to dataframe. |
data2 |
Dataframe of 2nd GWAS results for comparison. |
chrom |
Vector determines which column in |
pos |
Determines which column in |
p |
Determines which column in |
labs |
Determines which column in |
No return value. Prints diagnostic messages.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.